from time import sleep
from hytest import *
import sys
import os
# 获取当前脚本的绝对路径
current_dir = os.path.dirname(os.path.abspath(__file__))
# 构建预定系统的绝对路径
预定系统_path = os.path.abspath(os.path.join(current_dir, '..','..','..'))
# 添加路径
sys.path.append(预定系统_path)
# 导入模块
try:
    from 预定系统.Base.base import *
except ModuleNotFoundError as e:
    print(f"ModuleNotFoundError: {e}")
    print("尝试使用绝对路径导入")
    from 预定系统.Base.base import *

# 提取常量
XPATH_USERNAME_INPUT = '//*[@id="app"]/div/div[3]/div[1]/div[2]/div/form/div[1]/div/input'
# 用户名输入框的 XPath 路径

XPATH_PASSWORD_INPUT = '//*[@id="app"]/div/div[3]/div[1]/div[2]/div/form/div[2]/div/input'
# 密码输入框的 XPath 路径

XPATH_CODE_INPUT = '//*[@id="app"]/div/div[3]/div[1]/div[2]/div/form/div[3]/div[1]/div/input'
# 验证码输入框的 XPath 路径

XPATH_LOGIN_BUTTON = '//*[@id="app"]/div/div[3]/div[1]/div[2]/div/form/div[4]/input'
# 登录按钮的 XPath 路径

XPATH_WELCOME_TEXT = '//*[@id="app"]/div/div[1]/div/span[1]'
# 欢迎文本的 XPath 路径

CLASS_MESSAGE_CONTENT = 'el-message__content'
# 消息内容的 CSS 类名

DEFAULT_WAIT_TIME = 20
# 默认等待时间（秒），用于元素加载或操作之间的等待


def clear_and_send_keys(wd, locator, value):
    """
    清空输入框并发送指定值

    该函数首先等待指定的元素变得可点击，然后清空该元素的内容，
    最后向该元素发送指定的值。这个过程常用于表单填写自动化。

    参数:
    - wd: WebDriver实例，用于与浏览器交互。
    - locator: 定位器，用于定位页面上的元素。
    - value: 需要发送到元素的值，通常为字符串。

    返回值:
    无
    """
    # 等待元素变得可点击，这是为了确保元素已经加载完成并且可以接收输入
    element = WebDriverWait(wd, DEFAULT_WAIT_TIME).until(EC.element_to_be_clickable(locator))

    # 清空元素的内容，通常用于输入框，以确保之前的内容不会影响新的输入
    element.clear()

    # 向元素发送指定的值，这是自动化表单填写的关键步骤
    element.send_keys(value)


class Login_00x:

    ddt_cases = [
        {
            'name': '登录 UI_001',
            'para': [None,'Ubains@4321','csba','请输入账号!']
        },
        {
            'name': '登录 UI_002',
            'para': ['admin@czj',None,'csba','请输入密码!']
        },
        {
            'name': '登录 UI_003',
            'para': ['admin@czj','Ubains@4321',None,'请输入验证码!']
        },
        {
            'name': '登录 UI_004',
            'para': ['admin@czj112','Ubains@4321','csba','账号或密码错误']
        },
        {
            'name': '登录 UI_005',
            'para': ['adM 12in@czj','Ubains@4321','csba','账号或密码错误']
        },
        {
            'name': '登录 UI_006',
            'para': ['admin@czj', '12345', 'csba', '账号或密码错误']
        },
        {
            'name': '登录 UI_007',
            'para': ['admin@czj', 'U bains1s@432', 'csba', '账号或密码错误']
        },
        {
            'name': '登录 UI_008',
            'para': ['admin@czj', 'Ubains@4321', '123', '验证码错误']
        },
        {
            'name': '登录 UI_009',
            'para': ['admin@czj', 'Ubains@4321', 'cs 12', '验证码错误']
        },
        {
            'name': '登录 UI_010',
            'para': ['admin@czj', 'Ubains@4321', 'csba', '欢迎 预定标准版测试']
        }
    ]

    def teststeps(self):
        """
        执行测试步骤以验证登录功能。
        本函数根据参数输入账号、密码和验证码，并检查登录后的提示信息是否与预期相符。
        """
        # 初始化通知文本为空字符串
        notify_text = ""
        # 从全局存储中获取webdriver实例
        wd = GSTORE['wd']
        # 从self.para中解构出用户名、密码、验证码和检查文本
        username, password, code, check_text = self.para

        # 步骤1：输入账号、密码和验证码
        STEP(1, f"输入账号: {username}, 密码: {password}, 验证码: {code}")
        # 如果用户名不为空，则清空用户名输入框并输入用户名
        if username is not None:
            clear_and_send_keys(wd, (By.XPATH, XPATH_USERNAME_INPUT), username)

        # 如果密码不为空，则清空密码输入框并输入密码
        if password is not None:
            clear_and_send_keys(wd, (By.XPATH, XPATH_PASSWORD_INPUT), password)

        # 如果验证码不为空，则清空验证码输入框并输入验证码
        if code is not None:
            clear_and_send_keys(wd, (By.XPATH, XPATH_CODE_INPUT), code)

        # 步骤2：点击登录按钮
        STEP(2, "点击登录按钮")
        # 等待登录按钮可点击，并点击它
        login_button = WebDriverWait(wd, DEFAULT_WAIT_TIME).until(
            EC.element_to_be_clickable((By.XPATH, XPATH_LOGIN_BUTTON)))
        login_button.click()

        # 等待1秒以允许页面响应
        sleep(2)
        SELENIUM_LOG_SCREEN(wd)
        # 根据预期的检查文本类型，获取并记录提示信息
        if check_text == "欢迎 预定标准版测试":
            notify_text = WebDriverWait(wd, DEFAULT_WAIT_TIME).until(
                EC.presence_of_element_located((By.XPATH, XPATH_WELCOME_TEXT))
            ).text
            INFO(f"Alert text: {notify_text}")
        else:
            try:
                notify_text = WebDriverWait(wd, DEFAULT_WAIT_TIME).until(
                    EC.presence_of_element_located((By.CLASS_NAME, CLASS_MESSAGE_CONTENT))
                ).text
                INFO(f"Alert text: {notify_text}")
            except Exception as e:
                INFO(f"Exception occurred: {e}")

        # 步骤3：校验提示信息
        STEP(3, f"校验提示信息: {check_text}")
        # 设置隐式等待时间
        wd.implicitly_wait(DEFAULT_WAIT_TIME)
        # 检查点：验证提示信息是否与预期相符
        CHECK_POINT('弹出提示', notify_text == check_text)

    def teardown(self):
        """
        测试 teardown 方法，用于测试结束后清理环境。

        该方法从全局存储 GSTORE 中获取 WebDriver 实例，并在测试结束前刷新当前页面。
        这是为了确保每个测试都是在干净的状态下执行，避免不同测试之间相互影响。
        """
        # 从全局存储中获取 WebDriver 实例
        wd = GSTORE['wd']

        # 执行步骤 4：刷新页面，以确保下一个测试从一个干净的状态开始
        STEP(4, "刷新页面")
        wd.refresh()